"""Contains all common constants used in the Robinhood Client library."""

BASE_API_URL = "https://api.robinhood.com"
API_LOGIN_URL = f"{BASE_API_URL}/oauth2/token/"
BASE_NUMMUS_URL = "https://nummus.robinhood.com"
BASE_PHOENIX_URL = "https://phoenix.robinhood.com"
BASE_MINERVA_URL = "https://minerva.robinhood.com"
BASE_BONFIRE_URL = "https://bonfire.robinhood.com"

DEFAULT_PAGE_SIZE = 10
